@@ -38,6 +38,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 
@@ -47,25 +49,25 @@ class ConstructMetadata(
 ):
     '''Metadata keys used by constructs.'''
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="DISABLE_STACK_TRACE_IN_METADATA")
     def DISABLE_STACK_TRACE_IN_METADATA(cls) -> builtins.str:
         '''If set in the construct's context, omits stack traces from metadata entries.'''
         return typing.cast(builtins.str, jsii.sget(cls, "DISABLE_STACK_TRACE_IN_METADATA"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ERROR_METADATA_KEY")
     def ERROR_METADATA_KEY(cls) -> builtins.str:
         '''Context type for error level messages.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ERROR_METADATA_KEY"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="INFO_METADATA_KEY")
     def INFO_METADATA_KEY(cls) -> builtins.str:
         '''Context type for info level messages.'''
         return typing.cast(builtins.str, jsii.sget(cls, "INFO_METADATA_KEY"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="WARNING_METADATA_KEY")
     def WARNING_METADATA_KEY(cls) -> builtins.str:
         '''Context type for warning level messages.'''
@@ -83,6 +85,11 @@ class ConstructOptions:
 
         :param node_factory: A factory for attaching ``Node``s to the construct. Default: - the default ``Node`` is associated
         '''
+        if __debug__:
+            def stub(*, node_factory: typing.Optional[INodeFactory] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument node_factory", value=node_factory, expected_type=type_hints["node_factory"])
         self._values: typing.Dict[str, typing.Any] = {}
         if node_factory is not None:
             self._values["node_factory"] = node_factory
@@ -130,6 +137,12 @@ class Dependency:
         :param source: Source the dependency.
         :param target: Target of the dependency.
         '''
+        if __debug__:
+            def stub(*, source: IConstruct, target: IConstruct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument source", value=source, expected_type=type_hints["source"])
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         self._values: typing.Dict[str, typing.Any] = {
             "source": source,
             "target": target,
@@ -185,6 +198,11 @@ class _IAspectProxy:
 
         :param node: -
         '''
+        if __debug__:
+            def stub(node: IConstruct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument node", value=node, expected_type=type_hints["node"])
         return typing.cast(None, jsii.invoke(self, "visit", [node]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -246,6 +264,13 @@ class _INodeFactoryProxy:
         :param scope: the construct's scope (parent).
         :param id: the construct id.
         '''
+        if __debug__:
+            def stub(host: Construct, scope: IConstruct, id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument host", value=host, expected_type=type_hints["host"])
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast("Node", jsii.invoke(self, "createNode", [host, scope, id]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -259,7 +284,7 @@ class ISynthesisSession(typing_extensions.Protocol):
     Passed into ``construct.onSynthesize()`` methods.
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="outdir")
     def outdir(self) -> builtins.str:
         '''The output directory for this synthesis session.'''
@@ -274,7 +299,7 @@ class _ISynthesisSessionProxy:
 
     __jsii_type__: typing.ClassVar[str] = "constructs.ISynthesisSession"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="outdir")
     def outdir(self) -> builtins.str:
         '''The output directory for this synthesis session.'''
@@ -339,6 +364,18 @@ class MetadataEntry:
         :param type: The metadata entry type.
         :param trace: Stack trace. Can be omitted by setting the context key ``ConstructMetadata.DISABLE_STACK_TRACE_IN_METADATA`` to 1. Default: - no trace information
         '''
+        if __debug__:
+            def stub(
+                *,
+                data: typing.Any,
+                type: builtins.str,
+                trace: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument data", value=data, expected_type=type_hints["data"])
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument trace", value=trace, expected_type=type_hints["trace"])
         self._values: typing.Dict[str, typing.Any] = {
             "data": data,
             "type": type,
@@ -393,15 +430,27 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param scope: -
         :param id: -
         '''
+        if __debug__:
+            def stub(host: Construct, scope: IConstruct, id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument host", value=host, expected_type=type_hints["host"])
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [host, scope, id])
 
-    @jsii.member(jsii_name="of") # type: ignore[misc]
+    @jsii.member(jsii_name="of")
     @builtins.classmethod
     def of(cls, construct: IConstruct) -> "Node":
         '''Returns the node associated with a construct.
 
         :param construct: the construct.
         '''
+        if __debug__:
+            def stub(construct: IConstruct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument construct", value=construct, expected_type=type_hints["construct"])
         return typing.cast("Node", jsii.sinvoke(cls, "of", [construct]))
 
     @jsii.member(jsii_name="addDependency")
@@ -413,6 +462,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param dependencies: -
         '''
+        if __debug__:
+            def stub(*dependencies: IConstruct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument dependencies", value=dependencies, expected_type=typing.Tuple[type_hints["dependencies"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addDependency", [*dependencies]))
 
     @jsii.member(jsii_name="addError")
@@ -423,6 +477,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param message: The error message.
         '''
+        if __debug__:
+            def stub(message: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "addError", [message]))
 
     @jsii.member(jsii_name="addInfo")
@@ -433,6 +492,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param message: The info message.
         '''
+        if __debug__:
+            def stub(message: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "addInfo", [message]))
 
     @jsii.member(jsii_name="addMetadata")
@@ -452,6 +516,17 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param data: the value of the metadata (can be a Token). If null/undefined, metadata will not be added.
         :param from_function: a function under which to restrict the metadata entry's stack trace (defaults to this.addMetadata).
         '''
+        if __debug__:
+            def stub(
+                type: builtins.str,
+                data: typing.Any,
+                from_function: typing.Any = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument data", value=data, expected_type=type_hints["data"])
+            check_type(argname="argument from_function", value=from_function, expected_type=type_hints["from_function"])
         return typing.cast(None, jsii.invoke(self, "addMetadata", [type, data, from_function]))
 
     @jsii.member(jsii_name="addValidation")
@@ -463,6 +538,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param validation: -
         '''
+        if __debug__:
+            def stub(validation: IValidation) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument validation", value=validation, expected_type=type_hints["validation"])
         return typing.cast(None, jsii.invoke(self, "addValidation", [validation]))
 
     @jsii.member(jsii_name="addWarning")
@@ -474,6 +554,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param message: The warning message.
         '''
+        if __debug__:
+            def stub(message: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "addWarning", [message]))
 
     @jsii.member(jsii_name="applyAspect")
@@ -482,6 +567,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param aspect: -
         '''
+        if __debug__:
+            def stub(aspect: IAspect) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument aspect", value=aspect, expected_type=type_hints["aspect"])
         return typing.cast(None, jsii.invoke(self, "applyAspect", [aspect]))
 
     @jsii.member(jsii_name="findAll")
@@ -493,6 +583,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param order: -
         '''
+        if __debug__:
+            def stub(order: typing.Optional[ConstructOrder] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
         return typing.cast(typing.List[IConstruct], jsii.invoke(self, "findAll", [order]))
 
     @jsii.member(jsii_name="findChild")
@@ -505,6 +600,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :return: Child with the given id.
         '''
+        if __debug__:
+            def stub(id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast(IConstruct, jsii.invoke(self, "findChild", [id]))
 
     @jsii.member(jsii_name="prepare")
@@ -522,6 +622,12 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param key: The context key.
         :param value: The context value.
         '''
+        if __debug__:
+            def stub(key: builtins.str, value: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "setContext", [key, value]))
 
     @jsii.member(jsii_name="synthesize")
@@ -554,6 +660,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :return: the child if found, or undefined
         '''
+        if __debug__:
+            def stub(id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast(typing.Optional[IConstruct], jsii.invoke(self, "tryFindChild", [id]))
 
     @jsii.member(jsii_name="tryGetContext")
@@ -566,6 +677,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :return: The context value or ``undefined`` if there is no context value for thie key.
         '''
+        if __debug__:
+            def stub(key: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
         return typing.cast(typing.Any, jsii.invoke(self, "tryGetContext", [key]))
 
     @jsii.member(jsii_name="tryRemoveChild")
@@ -578,6 +694,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :stability: experimental
         '''
+        if __debug__:
+            def stub(child_name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument child_name", value=child_name, expected_type=type_hints["child_name"])
         return typing.cast(builtins.bool, jsii.invoke(self, "tryRemoveChild", [child_name]))
 
     @jsii.member(jsii_name="validate")
@@ -588,13 +709,13 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(typing.List["ValidationError"], jsii.invoke(self, "validate", []))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="PATH_SEP")
     def PATH_SEP(cls) -> builtins.str:
         '''Separator used to delimit construct path components.'''
         return typing.cast(builtins.str, jsii.sget(cls, "PATH_SEP"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="addr")
     def addr(self) -> builtins.str:
         '''Returns an opaque tree-unique address for this construct.
@@ -611,24 +732,23 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         Example::
 
-            # Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
             c83a2846e506bcc5f10682b564084bca2d275709ee
         '''
         return typing.cast(builtins.str, jsii.get(self, "addr"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="children")
     def children(self) -> typing.List[IConstruct]:
         '''All direct children of this construct.'''
         return typing.cast(typing.List[IConstruct], jsii.get(self, "children"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dependencies")
     def dependencies(self) -> typing.List[Dependency]:
         '''Return all dependencies registered on this node or any of its children.'''
         return typing.cast(typing.List[Dependency], jsii.get(self, "dependencies"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="id")
     def id(self) -> builtins.str:
         '''The id of this construct within the current scope.
@@ -637,13 +757,13 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(builtins.str, jsii.get(self, "id"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="locked")
     def locked(self) -> builtins.bool:
         '''Returns true if this construct or the scopes in which it is defined are locked.'''
         return typing.cast(builtins.bool, jsii.get(self, "locked"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="metadata")
     def metadata(self) -> typing.List[MetadataEntry]:
         '''An immutable array of metadata objects associated with this construct.
@@ -652,7 +772,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(typing.List[MetadataEntry], jsii.get(self, "metadata"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="path")
     def path(self) -> builtins.str:
         '''The full, absolute path of this construct in the tree.
@@ -661,7 +781,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(builtins.str, jsii.get(self, "path"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="root")
     def root(self) -> IConstruct:
         '''Returns the root of the construct tree.
@@ -670,7 +790,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(IConstruct, jsii.get(self, "root"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="scopes")
     def scopes(self) -> typing.List[IConstruct]:
         '''All parent scopes of this construct.
@@ -683,7 +803,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(typing.List[IConstruct], jsii.get(self, "scopes"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="uniqueId")
     def unique_id(self) -> builtins.str:
         '''(deprecated) A tree-global unique alphanumeric identifier for this construct.
@@ -701,7 +821,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(builtins.str, jsii.get(self, "uniqueId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="scope")
     def scope(self) -> typing.Optional[IConstruct]:
         '''Returns the scope in which this construct is defined.
@@ -710,7 +830,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(typing.Optional[IConstruct], jsii.get(self, "scope"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="defaultChild")
     def default_child(self) -> typing.Optional[IConstruct]:
         '''Returns the child construct that has the id ``Default`` or ``Resource"``.
@@ -734,6 +854,11 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
     @default_child.setter
     def default_child(self, value: typing.Optional[IConstruct]) -> None:
+        if __debug__:
+            def stub(value: typing.Optional[IConstruct]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "defaultChild", value)
 
 
@@ -760,6 +885,18 @@ class SynthesisOptions:
         :param session_context: Additional context passed into the synthesis session object when ``construct.synth`` is called. Default: - no additional context is passed to ``onSynthesize``
         :param skip_validation: Whether synthesis should skip the validation phase. Default: false
         '''
+        if __debug__:
+            def stub(
+                *,
+                outdir: builtins.str,
+                session_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+                skip_validation: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument outdir", value=outdir, expected_type=type_hints["outdir"])
+            check_type(argname="argument session_context", value=session_context, expected_type=type_hints["session_context"])
+            check_type(argname="argument skip_validation", value=skip_validation, expected_type=type_hints["skip_validation"])
         self._values: typing.Dict[str, typing.Any] = {
             "outdir": outdir,
         }
@@ -822,6 +959,12 @@ class ValidationError:
         :param message: The error message.
         :param source: The construct which emitted the error.
         '''
+        if __debug__:
+            def stub(*, message: builtins.str, source: Construct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
+            check_type(argname="argument source", value=source, expected_type=type_hints["source"])
         self._values: typing.Dict[str, typing.Any] = {
             "message": message,
             "source": source,
@@ -874,6 +1017,17 @@ class Construct(metaclass=jsii.JSIIMeta, jsii_type="constructs.Construct"):
         :param id: The scoped construct ID. Must be unique amongst siblings. If the ID includes a path separator (``/``), then it will be replaced by double dash ``--``.
         :param node_factory: A factory for attaching ``Node``s to the construct. Default: - the default ``Node`` is associated
         '''
+        if __debug__:
+            def stub(
+                scope: Construct,
+                id: builtins.str,
+                *,
+                node_factory: typing.Optional[INodeFactory] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = ConstructOptions(node_factory=node_factory)
 
         jsii.create(self.__class__, self, [scope, id, options])
@@ -900,6 +1054,11 @@ class Construct(metaclass=jsii.JSIIMeta, jsii_type="constructs.Construct"):
 
         :param session: The synthesis session.
         '''
+        if __debug__:
+            def stub(session: ISynthesisSession) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument session", value=session, expected_type=type_hints["session"])
         return typing.cast(None, jsii.invoke(self, "onSynthesize", [session]))
 
     @jsii.member(jsii_name="onValidate")
